Information on: Search Court Opinions

- Court of Appeals
  - Organization
    - Chief Judge Washington
    - Judges
    - Attorney Discipline
    - Calendars
    - Clerk of the Court
    - Committee on Admissions
    - Committee on Unauthorized Practice of Law
    - Forms
    - Notices
    - Oral Arguments
    - Orders
    - Representing Yourself
  - Featured Topics
    - 2009 Citation Guide
    - 2010 Caseload Stats
    - Annual Reports
    - Civil Apps Screening Stmt
    - DC Code of Judicial Conduct
    - For CJA Attys
    - Fundamentals of Practice in DCCA
    - Historic Courthouse
    - Internal Operating Procs
    - DCCA Rules
    - Organizational Structure
  - Online Services
    - MOJs
    - , Opinions
    - , Streaming Oral Arguments
    - , Web Voucher System
    - , Getting Here
- Superior Court
  - Organization
    - Chief Judge Satterfield
    - Judges/Assignments
    - Clerk of the Court
    - Civil Division
      Civil Actions, Quality Review, Landlord & Tenant, more...
    - Crime Victims Compensation Program
      Eligibility, Procedures, Compensable Costs, more...
    - Criminal Division
      Community Courts, Drug Court, Ad Hoc Committee on Wrongful Convictions, more...
    - Domestic Violence Unit
      Intake Centers, Supervised Visitation Center, more...
    - Family Court Operations Division
      Intake Center, Child Abuse, Domestic Relations, more...
    - Family Court Social Services Division
      Status Offender, Deliquency Prevention, Intake, more...
    - Multi-Door Dispute Resolution Division
      Arbitration, Child Protection, Community Info, more...
    - Office of the Auditor-Master
    - Probate Division
      Large Estates, Small Estates, Foreign Estates, more...
    - Special Operations Division
      Appeals Coordinator, Jurors' Office, Child Care Center, more...
    - Tax Division
  - Featured Topics
    - Administrative Orders
    - DC Code of Judicial Conduct
    - Jury Duty
    - Rules of the D.C. Superior Court
    - Adoption Day
    - Organizational Structure
  - Online Services
    - Active Warrant List
    - , Court Cases Online
    - , Courtroom Calendars
    - , eFiling
    - , Web Voucher System
    - , Getting Here
- Court System
  - Organization
    - Administrative Services
      Procurement & Contracts Branch
    - Budget & Finance
    - Capital Projects & Facilities Management
    - Center for Education & Training
    - Court Reporting & Recording
    - Executive Office
    - General Counsel's Office
    - Human Resources
      Job Opportunities
    - Information Technology
    - Research & Development
  - Featured Topics
    - Annual Reports
    - Contracting Opportunities
    - Information Technology Initiatives
    - Job Opportunities
    - Organizational Structure
  - Online Services
    - Getting Here

- HOME
- PUBLIC
  - How Do I...
    - Appeals Matters
    - Civil Matters
      Small Claims, Landlord and Tenant, more...
    - Crime Victims Compensation Matters
    - Criminal Matters
      Get Information On An Arrest, Understand the arraignment process, My traffic violations, more...
    - Divorce Matters
    - Domestic Violence Matters
      Get a Protection Order, Call for help, File a case, more...
    - Emergency Matters
    - Family Matters
      Child abuse case info, Adopting a child, Intake Center, more...
    - Juvenile Matters
      About My Child's Arrest, Truancy, Child Guidance Clinic, more...
    - Marriage Matters
      Get Married, more...
    - Mediation Matters
      Get help solving a dispute, Arbitration, Landlord and Tenant, more...
    - Probate Matters
      Guardianship of Minors Estates (GDN), Responsible for an adult, more...
    - Tax Matters
      Appeal without Attorney, Attending tax hearings, eFiling Tax Petition, more...
  - Featured Topics
    - Arranging for Child Care
    - If you need an Interpreter
    - Representing Yourself
    - Job Opportunities
  - Online Services
    - Active Warrant List
    - , Court Cases Online
    - , FAQs
    - , Forms
    - , Getting Here
    - , Legal Glossary
- JURORS
  - Get Info On...
    - Child Care
    - Deferrals
    - During Your Jury Service
    - Getting Paid
    - Grand Jury Service
    - Accommodations/Amenities
    - Jury Fee Act
    - Where to Report
    - Petit Jury Service
    - Planning Your Service
    - Receiving a Summons
    - Safety & Security
    - Show Cause Hearings
    - Upon your Arrival
    - Using eJuror
  - Featured Topics
    - Jury Duty in the News
    - FBI Identity Thieves
    - Using a Segway
    - Interpreter
  - Online Services
    - eJuror
    - , FAQs
    - , Getting Here
- LEGAL PROFESSIONALS
  - Get Info On...
    - Appeals Matters
    - Civil Matters
      Landlord and Tenant, Small Claims, more...
    - Criminal Matters
      Criminal Forms, Criminal Statistics, Community Courts, Ad Hoc Committee on Wrongful Convictions, more...
    - Domestic Violence Matters
      Conference Materials, Victim Advocates, more...
    - Emergency Matters
    - Family Matters
      Central Intake Center, Domestic Relations, Marriage Bureau, more...
    - Mediation Matters
      Arbitration, Civil Mediation, Landlord & Tenant, more...
    - Probate Matters
      more...
    - Tax Matters
      Filing Process, Initiating Petition, Case Proceedings, more...
  - Featured Topics
    - Criminal Division Attorney Calendar
    - Admissions, Discipline & Unauthorized Practice of Law
    - Pro Bono Honor Roll
    - Court of Appeals Orders
    - Court of Appeals Notices
    - Court of Appeals Rules
    - Superior Court Administrative Orders
    - Superior Court Rules
    - CJA Program Attorneys
    - CCAN Program Attorneys
  - Online Services
    - Court Cases Online
    - , Court Calendars
    - , eFiling
    - , MOJs
    - , Opinions
    - , Streaming Oral Arguments
    - , Web Voucher System
    - , Web Mediation System
    - , FAQs
    - , Forms
    - , Getting Here
- MEDIA
  - Get Info On...
    - Adoption Day
    - Community Courts
    - Crime Victims Compensation
    - Marriage Bureau
    - Media Coverage Archive
    - Press Releases & Advisories
    - Safe Surrender
    - Wills Project
    - Housing Conditions Calendar
    - Jury Duty
    - Drug Court
    - Media Coverage
    - Family Celebration Day
    - Family Treatment Court
    - Fathering Court
    - Historic Courthouse
  - Featured Topics
    - Annual Reports
    - Budget Requests
    - DCCourtsNews Web Magazine
    - DC Code of Judicial Conduct
    - Full Court Press
    - Journalists’ Guide to DC Courts
    - Jury Duty in the News
    - Strategic Plan
    - Electronic Device Policy
    - Ordering Transcripts
  - Online Services
    - Active Warrant List
    - , Court Cases Online
    - , Court Calendars
    - , Getting Here
    - , Legal Glossary
- ABOUT
  - Get Info On...
    - Accessibility & Disability
      Relay Service, Requesting Accommodations, Architectural Features, Use of Segways and Other Mobility Devices, more...
    - Court Visitors Program
    - Courts' Newsletter
    - Getting Here
      Addresses and Phones, Public Transportation, more...
    - Interns & Volunteers
      Internships, Volunteering as a Mediator
    - Job Opportunities
      How to Apply
    - Mediation
    - Joint Committee
    - Judiciary Square
    - Kids & Students
    - Organizational Performance
      Annual Reports, Budget Requests, Strategic Planning, more...
    - Organizational Structure
    - Safety & Security
      Evacuation, Recording Devices, more...
  - Featured Topics
    - Historic Courthouse Restoration
    - Code of Judicial Conduct
  - Online Services
    - Court Cases Online
    - , FAQs
    - , Getting Here
    - , Legal Glossary

- Search D.C. Court of Appeals Opinions
  Opinions of the D.C. Court of Appeals may be either published or unpublished. Signed opinions and per curiam opinions are published. The court may also publish orders, including matters involving attorney discipline. Memorandum Opinions and Judgments (MOJs) are not published. Opinions published by this court from mid-1998 to the present are available on this website. Also available are monthly lists of MOJs issued since September 1999.
  - The DC Court of Appeals case numbers include a two-letter case code that identifies the type of case or, if an appeal from a city agency, the source of the appeal.
    Errata Sheet
  - How can we improve the Opinions / MOJs Search page? Send your feedback to webmaster@dcsc.gov.

- Date Range
  - From
  - Through

- Case Number | Case Name | Released | Errata | Atlantic Citation
  --- | --- | --- | --- | ---
  11-CM-1134 | Charles A. Grant v. United States | Feb 20, 2014 |  |
  13-BG-1076 | In re Lily Mazahery | Feb 20, 2014 |  |
  13-BG-1247 | In re Charles P. Ingenito | Feb 20, 2014 |  |
  13-BG-1257 | In re Mira S. Burghardt | Feb 20, 2014 |  |
  13-BG-1267 | In re Brian R. Dinning | Feb 20, 2014 |  |
  14-BG-13 | In re Benito A. Garza | Feb 20, 2014 |  |
  11-BG-775 | In re Kenneth A. Martin | Feb 13, 2014 |  |
  11-BG-775 Amended | In re Kenneth A. Martin* | Feb 13, 2014 |  |
  12-AA-923 | Rayburn L. Levy v. District of Columbia Department of Employment Services and Washington Metropolitan Area Transit Authority | Feb 6, 2014 |  |
  12-CV-695+ | Aeon Financial, LLC v. District of Columbia | Feb 6, 2014 |  |
  12-CV-711 | Ricardo Hernandez v. Bryant Banks, et al. | Feb 6, 2014 |  |
  12-FM-76+ | Natalie Khawam v. Grayson P. Wolfe | Feb 6, 2014 |  |
  14-BS-63 | In re: Stephanie Y. Bradley | Feb 6, 2014 |  |
  14-BS-64 | In re: Karen J. Miller | Feb 6, 2014 |  |
  11-CV-1206+ | Daniel Wolf and Maia Caplan Kats v. Sprenger + Lang, PLLC, et al.* | Jan 30, 2014 |  |
  12-CF-745 | Denardo S. Hopkins v. United States | Jan 30, 2014 |  |
  12-CM-1211+ | Lurisa Lindsay and Terrance Dean Davis v. United States | Jan 30, 2014 |  |
  14-BG-6 | In re Maria I. Gonzalez | Jan 30, 2014 |  |
  12-AA-418 | Nathalia L. Brown v. District of Columbia Department of Employment Services and Potomac Electrical Power Company | Jan 23, 2014 |  |
  13-AA-262 | Leslie Randolph, et al v. District of Columbia Zoning Commission and Hoffman-Struever Waterfront, LLC | Jan 23, 2014 |  |
  13-BG-52 | In re Sandy Chang | Jan 23, 2014 |  |
  98-CF-1088, 98-CF-1425 and 04-CO-1503 | Colie L. Long v. United States | Jan 23, 2014 |  |
  12-CV-416 | Sinobia Newell-Brinkley v. Diana Haines Walton, et al. | Jan 16, 2014 |  |
  13-BG-18 | In re David H. Loomis | Jan 9, 2014 |  |
  12-CV-107 | Lucas Wall v. Lucinda Barbers, et al. | Jan 2, 2014 |  |
  12-CV-351 | Fraternal Order of Police, Metropolitan Labor Committee v. District of Columbi | Jan 2, 2014 |  |
  11-CV-1622 & 12-CV-1227 | The Kamit Institute for Magnificent Achievers v. District of Columbia Public Charter School Board, et al. | Dec 26, 2013 |  |
  13-BG-1056 | In re: Frank B. Cegelski | Dec 26, 2013 |  |
  13-BG-1072 | In re: Garland H. Stillwell | Dec 26, 2013 |  |
  11-CM-1154 & 12-CO-874 | Adam Jaramillo Ortberg v. United States | Dec 19, 2013 |  |
  12-AA-466 | District of Columbia Office of Tax and Revenue v. John R. Shuman and Sara G. Shuman | Dec 19, 2013 |  |
  12-CF-1448 | James M. Schools v. United States | Dec 19, 2013 |  |
  13-BG-981 | In re Rosemary Foster | Dec 19, 2013 |  |
  13-CV-333 | George C. Papageorge v. Matt Banks, et al. | Dec 19, 2013 |  |
  10-CF-181 | Jermyl Moody v. United States | Dec 13, 2013 |  |
  05-CO-1261 & 05-CO-1262 | Wallace G. Mitchell v. United States | Dec 12, 2013 |  |
  10-CF-1184 & 10-CF-1232 | Emanuel Jenkins and Azariah Israel v. United States | Dec 12, 2013 |  |
  11-CV-609 | Ronda Nunnally v. District of Columbia Metropolitan Police Department | Dec 12, 2013 |  |
  11-CV-614 | Daniel Logan v. LaSalle Bank National Association, et al. | Dec 12, 2013 |  |
  11-CV-937 | Elliotte Patrick Coleman v. District of Columbia | Dec 12, 2013 |  |
  12-CV-195 | Johnnie P. Battle, et al. v. District of Columbia | Dec 12, 2013 |  |
  13-BG-51 | In re J. Scott Brown | Dec 12, 2013 |  |